/* Regressions for paper "Institutions and Economic Performance:
Endogeneity and Parameter Heterogeneity" 
by Theo Eicher and Andreas Leukert
;this version: 10.10.2007*/
/* The do-file reproduces the tables of the paper: tables 1-6 and A1*/
/**** Codes needed to be installed from internet: ivreg2;  grqreg  ****/
/*** Required stata datasets as used in this do-file: HJorigdata_oecd8899_WBincomegroupssugar.dta; 
ALLoecd2dum8899sugar.dta; 1900.dta; Ourdata_perssonalloecddummies.dta; 
HJSachsandpolitcalInstituions8899.dta (5 stata datasets contained in the ZIP-file data_eicher_leukert***/


# delimit;
clear;
set memory 20000;
set more off;
capture log close;
set matsize 500;

/* Start a log file, this displays all results in a text-file */
log using EL.log, replace;

display "This version: $S_DATE $S_TIME";

/* Table 1 */
/*full HJ Sample*/
use HJorigdata_oecd8899_WBincomegroupssugar.dta;
/* Regressions (I) and (II): Global Sample */ 
ivreg2 logyl (socinf=  engfrac eurfrac logfrankrom latitude), first; 
ivreg2 logyl (socinf=  engfrac eurfrac logfrankrom latitude) oecd99, first; 

/* Regressions (III) and (IV): OECD and NON OECD */
ivreg2 logyl (socinf=  engfrac eurfrac logfrankrom latitude) if oecd99==1, first; 
ivreg2 logyl (socinf=  engfrac eurfrac logfrankrom latitude) if oecd99==0, first; 

/* Regressions (III') and (IV'): adding wheat sugar ratio*/
ivreg2 logyl (socinf=  engfrac eurfrac logfrankrom latitude sugar) if oecd99==1, first; 
ivreg2 logyl (socinf=  engfrac eurfrac logfrankrom latitude sugar) if oecd99==0, first; 


/* Table 2 */
use ALLoecd2dum8899sugar.dta;
ivreg2 logyl (socinf=  xconst xrreg), first; 
ivreg2 logyl (socinf=  xconst xrreg engfrac eurfrac logfrankrom latitude), orthog(xconst xrreg) first; 
ivreg2 logyl (socinf=  xconst xrreg) oecd99, first; 

/*Table 3 */
/* Creation Of non-Oecd dummies and interaction terms*/
gen nonoecd99=1;
replace nonoecd99=0 if oecd99==1;
gen xconstoecd99=xconst*oecd99;
gen xrregoecd99=xrreg*oecd99;
gen xconstnonoecd99=xconst*nonoecd99;
gen xrregnonoecd99=xrreg*nonoecd99;

/* Regression (VIIIa) */
ivreg2 logyl (socinf=  xconst xrreg) if oecd99==1 , first; 

/* Regression (VIIIb) in 3 steps*/
reg socinf xconst xrreg xconstoecd99 xrregoecd99 oecd99 if logyl!=. & socinf!=.;
predict Iohat if logyl!=. & socinf!=.;
gen Iohat99=Iohat*oecd99;
reg logyl Iohat Iohat99 oecd99 if logyl!=. & socinf!=.;
/* delta method for combined effect of institutions a la Durlauf */
lincom Iohat+Iohat99;

/* Regression (VIIIc) */
ivreg2 logyl (socinf=  xconst xrreg sugar) if oecd99==1 , first; 

/* Regression (IXa) */
ivreg2 logyl (socinf=  xconst xrreg) if oecd99==0 , first; 

/* Regression (IXb) Global Sample with interactions */
reg socinf xconst xrreg xconstnonoecd99 xrregnonoecd99 nonoecd99 if logyl!=. & socinf!=.;
predict Inhat if logyl!=. & socinf!=.;
gen Inhat99=Inhat*nonoecd99;
reg logyl Inhat Inhat99 nonoecd99 if logyl!=. & socinf!=.;
/* delta method for combined effect of institutions a la Durlauf */
lincom Inhat+Inhat99;

/* Regression (IXc) */
ivreg2 logyl (socinf=  xconst xrreg sugar) if oecd99==0 , first; 

/* Figure 2 :Quantile graph */

reg socinf xconst xrreg if logyl!=. & socinf!=.;
predict Iohatx if logyl!=. & socinf!=.;
gen Iohat2x = Iohatx*Iohatx;
reg logyl Iohatx Iohat2x; 

sqreg logyl Iohatx, quantile(.1 .2 .3 .4 .5 .6 .7 .8 .9 .95) ;

qreg logyl Iohatx ;
grqreg Iohatx, ci;


/* Table 4 */
clear;
use 1900.dta;
ivreg2 logyl (socinf=xconst xrreg ),r  first;
ivreg2 logyl (socinf=xconst xrreg )if oecd99==1,  first;
ivreg2 logyl (socinf=xconst xrreg )if oecd99==0,  first;

/* Table 5 */
/**** NOTE: for programming convenience I name the 2 factors xconst and xrreg !!! 
So- whereever you see xconst and xrreg in output READ: Political Factor 1 and Pol factor 2 ***/
clear;
use ALLoecd2dum8899sugar.dta;
/*All Countries*/
/* factor Analysis: keeping 2 factor , naming them xconst and xrreg */
factor democ polity2 durable xrreg xrcomp xropen xconst parreg parcomp exrec polcomp demacc liec eiec  va polstab;
rotate, f(5);
score xconst1 xrreg1;
drop xconst;
drop xrreg;
gen xconst=xconst1;
gen xrreg=xrreg1;

/* XIII: Global */
ivreg2 logyl (socinf=xconst xrreg), first;

/* XIV: OECD */
ivreg2 logyl (socinf=xconst xrreg)if oecd99==1, first;

/* XV: Non OECD*/
ivreg2 logyl (socinf=xconst xrreg)if oecd99==0, first;


/* Table 5 second Part Persson data: */
clear;
use Ourdata_perssonalloecddummies.dta;
/* XVI: Global*/
ivreg2 logyl (socinf= demparl age), first;

/* XVII: OECD*/
ivreg2 logyl (socinf= demparl age) if oecd99==1, first;

/* XVIII: Non-OECD */
ivreg2 logyl (socinf= demparl age) if oecd99==0, first;


/* Table 6 */
clear;
use HJSachsandpolitcalInstituions8899.dta;
/* All Countries */
ivreg2  lgnp95 (exprop =xrreg xconst),r first;
/* Former Colonies */
ivreg2  lgnp95 (exprop =xrreg xconst)  if lmort!=.,r first;
/* Oecd */
ivreg2  lgnp95 (exprop =xrreg xconst)  if oecd99==1,r first;
/* Non-Oecd */
ivreg2  lgnp95 (exprop =xrreg xconst)  if oecd99==0,r first;

/* Appendix Tables */
clear;
use ALLoecd2dum8899sugar.dta;

/* Table A1 */

factor democ polity2 durable xrreg xrcomp xropen xconst parreg parcomp exrec polcomp demacc liec eiec  va polstab;
rotate, f(5);


log close; 


